pub struct Pattern { /* private fields */ }Expand description
Pattern represents a successfully parsed Relay pattern.
A pattern can be parsed/de-serialized from a string, serializing a pattern again may not produce the same original pattern but a normalized variant of the pattern.
let pattern = Pattern::builder("Foo**").case_insensitive(true).build().unwrap();
assert_eq!(&pattern.to_string(), "foo*");Patterns can be compared with other patterns, a pattern is considered equal with another pattern if its parsed and normalized forms and options are the same. Two patterns with the same options but built from different strings may compare equal if their normalized forms are the same.
let pattern1 = Pattern::builder("Foo**").case_insensitive(true).build().unwrap();
let pattern2 = Pattern::builder("foo*").case_insensitive(true).build().unwrap();
assert_eq!(&pattern1, &pattern2);
let pattern1 = Pattern::builder("Foo**").case_insensitive(true).build().unwrap();
let pattern2 = Pattern::builder("foo*").case_insensitive(false).build().unwrap();
assert_ne!(&pattern1, &pattern2);Implementations